@@ -139,6 +139,7 @@ guint dvb_channel_get_VideoPID (DVBChannel* self);
 char* dvb_channel_get_audio_pids_string (DVBChannel* self);
 guint dvb_channel_get_Sid (DVBChannel* self);
 static char* dvb_cable_channel_real_to_string (DVBChannel* base);
+DVBChannel* dvb_channel_construct (GType object_type);
 DVBCableChannel* dvb_cable_channel_new (void);
 DVBCableChannel* dvb_cable_channel_construct (GType object_type);
 void dvb_cable_channel_set_Inversion (DVBCableChannel* self, DVBDvbSrcInversion value);
@@ -178,7 +179,7 @@ static char* dvb_cable_channel_real_to_string (DVBChannel* base) {
 
 DVBCableChannel* dvb_cable_channel_construct (GType object_type) {
 	DVBCableChannel * self;
-	self = g_object_newv (object_type, 0, NULL);
+	self = (DVBCableChannel*) dvb_channel_construct (object_type);
 	return self;
 }
 
